@@ -9,7 +9,7 @@ import socket
 import struct
 import weakref
 
-from .util import find_library, load_kernel
+from .util import find_library, load_kernel, find_libc
 from .xtables import (XT_INV_PROTO, NFPROTO_IPV4, XTablesError, xtables,
                       xt_align, xt_counters, xt_entry_target, xt_entry_match)
 
@@ -26,7 +26,7 @@ if not hasattr(socket, 'IPPROTO_SCTP'):
 
 _IFNAMSIZ = 16
 
-_libc = ct.CDLL("libc.so.6")
+_libc = find_libc()
 _get_errno_loc = _libc.__errno_location
 _get_errno_loc.restype = ct.POINTER(ct.c_int)
 _malloc = _libc.malloc
@@ -419,6 +419,7 @@ class IPTCModule(object):
         res = shlex.split(buf)
         res.reverse()
         inv = False
+        key = None
         while len(res) > 0:
             x = res.pop()
             if x == '!':
@@ -433,7 +434,11 @@ class IPTCModule(object):
                     params[key] = []
                 inv = False
                 continue
-            params[key].append(x)  # This is a parameter value.
+            # At this point key should be set, unless the output from save is
+            # not formatted right. Let's be defensive, since some users
+            # reported that problem.
+            if key is not None:
+                params[key].append(x)  # This is a parameter value.
         return params
 
     def _update_parameters(self):
@@ -574,9 +579,7 @@ class Match(IPTCModule):
 
     def __eq__(self, match):
         basesz = ct.sizeof(xt_entry_match)
-        if (self.match.u.match_size == match.match.u.match_size and
-            self.match.u.user.name == match.match.u.user.name and
-            self.match.u.user.revision == match.match.u.user.revision and
+        if (self.name == match.name and
             self.match_buf[basesz:self.usersize] ==
                 match.match_buf[basesz:match.usersize]):
             return True
@@ -1064,9 +1067,6 @@ class Rule(object):
             saddr = _a_to_i(socket.inet_pton(socket.AF_INET, addr))
         except socket.error:
             raise ValueError("invalid address %s" % (addr))
-        ina = in_addr()
-        ina.s_addr = ct.c_uint32(saddr)
-        self.entry.ip.src = ina
 
         if not netm.isdigit():
             try:
@@ -1080,8 +1080,11 @@ class Rule(object):
             nmask = socket.htonl((2 ** imask - 1) << (32 - imask))
         neta = in_addr()
         neta.s_addr = ct.c_uint32(nmask)
-
         self.entry.ip.smsk = neta
+        # Apply subnet mask to IP address
+        ina = in_addr()
+        ina.s_addr = ct.c_uint32(saddr & nmask)
+        self.entry.ip.src = ina
 
     src = property(get_src, set_src)
     """This is the source network address with an optional network mask in
@@ -1125,9 +1128,6 @@ class Rule(object):
             daddr = _a_to_i(socket.inet_pton(socket.AF_INET, addr))
         except socket.error:
             raise ValueError("invalid address %s" % (addr))
-        ina = in_addr()
-        ina.s_addr = ct.c_uint32(daddr)
-        self.entry.ip.dst = ina
 
         if not netm.isdigit():
             try:
@@ -1142,6 +1142,10 @@ class Rule(object):
         neta = in_addr()
         neta.s_addr = ct.c_uint32(nmask)
         self.entry.ip.dmsk = neta
+        # Apply subnet mask to IP address
+        ina = in_addr()
+        ina.s_addr = ct.c_uint32(daddr & nmask)
+        self.entry.ip.dst = ina
 
     dst = property(get_dst, set_dst)
     """This is the destination network address with an optional network mask
@@ -1282,6 +1286,15 @@ class Rule(object):
         counters = self.entry.counters
         return counters.pcnt, counters.bcnt
 
+    def set_counters(self, counters):
+        """This method set a tuple pair of the packet and byte counters of
+        the rule."""
+        self.entry.counters.pcnt = counters[0]
+        self.entry.counters.bcnt = counters[1]
+
+    counters = property(get_counters, set_counters)
+    """This is the packet and byte counters of the rule."""
+
     # override the following three for the IPv6 subclass
     def _entry_size(self):
         return xt_align(ct.sizeof(ipt_entry))
