@@ -44,22 +44,6 @@ int wrap_parse(int (*fn)(int, char **, int, unsigned int *, void *, void **),
     return rv;
 }
 
-struct xt_option_call;
-int wrap_x6parse(void (*fn)(struct xt_option_call *),
-                 struct xt_option_call *cb)
-{
-    int err;
-
-    if ((err = setjmp(env)) == 0) {
-        fn(cb);
-    } else {
-        errno = err;
-        return -err;
-    }
-
-    return 0;
-}
-
 struct ipt_ip;
 void wrap_save(int (*fn)(const void *, const void *),
                const void *ip, const void *m)
@@ -68,3 +52,45 @@ void wrap_save(int (*fn)(const void *, const void *),
     fprintf(stdout, "\n"); /* make sure something is written to stdout */
     fflush(stdout);
 }
+
+int wrap_x6fn(void (*fn)(void *), void *data)
+{
+    int err;
+
+    if ((err = setjmp(env)) == 0) {
+        fn(data);
+    } else {
+        errno = err;
+        return -err;
+    }
+
+    return 0;
+}
+
+int wrap_uintfn(void (*fn)(unsigned int), unsigned int data)
+{
+    int err;
+
+    if ((err = setjmp(env)) == 0) {
+        fn(data);
+    } else {
+        errno = err;
+        return -err;
+    }
+
+    return 0;
+}
+
+int wrap_voidfn(void (*fn)(void))
+{
+    int err;
+
+    if ((err = setjmp(env)) == 0) {
+        fn();
+    } else {
+        errno = err;
+        return -err;
+    }
+
+    return 0;
+}
